#
# spec file for package python-Flask-Compress
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2016, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Flask-Compress
Version:        1.13
Release:        1.5
Summary:        Compress responses in Flask apps with gzip
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/colour-science/flask-compress
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Compress/Flask-Compress-%{version}.tar.gz
BuildRequires:  %{python_module Brotli}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli
Requires:       python-Flask
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Flask}
# /SECTION
%python_subpackages

%description
Flask-Compress allows compressing a Flask application's
responses with gzip.

The preferred solution is to have a server (like Nginx) automatically
compress the static files. If that option is not available,
Flask-Compress can solve the problem.

%prep
%setup -q -n Flask-Compress-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/flask_compress
%{python_sitelib}/Flask_Compress-%{version}-py*.egg-info
%pycache_only %{python_sitelib}/flask_compress/__pycache__

%changelog
* Sat Nov  5 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * use pytest
- update to version 1.13:
  * Re-enable compression for streaming, but hide it behind a new
    option COMPRESS_STREAMS that defaults to True. See #36
* Sun Jun  5 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.12:
  * Disable compression when response is streamed, see #31
* Sat Mar  5 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.11:
  * When compression is enabled, accept-encoding is always added to
    the Vary header, fixes #28
* Tue Sep 14 2021 pgajdos@suse.com
- %%check: actually test the package
* Thu Jul 22 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * include setuptools_scm, importlib-metadata
  * updated %%files section
- update to version 1.10.1:
  * no changelog available at the moment
- changes from version 1.10.0 :
  * Automate the release process with GitHub Actions
  * Use setuptools_scm to manage package versions
  * The layout is now an actual package rather than a single module
  * Clean up unused files
* Thu Nov 26 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.8.0:
  * Support ETag header as defined in RFC7232 #17
  * Implement per-view compression #14
- changes from version 1.7.0 :
  * The following parameters to control Brotli compression are now
    available: #10
    + COMPRESS_BR_MODE
    + COMPRESS_BR_LEVEL
    + COMPRESS_BR_WINDOW
    + COMPRESS_BR_BLOCK
  * Add deflate support, with COMPRESS_DEFLATE_LEVEL to control
    compression level (default is -1) #8
  * The default quality level for Brotli is now 4, which provides
    compression comparable to gzip at the default setting, while
    reducing the time required versus the Brotli default of 11
- changes from version 1.6.0:
  * Support for multiple compression algorithms and quality factors #7
  * Modified default compression settings to use Brotli when available
    before gzip
* Fri May 15 2020 Antonio Larrosa <alarrosa@suse.com>
- Brotli is actually required
* Sat May  2 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specifc in %%files section
  * upate project url
  * remove devel requirement
  * require python-Brotli for tests
- update to version 1.5.0:
  * Added brotli compression
  * Added tests
  * setup.py: Update url
  * Fix PyPI rendering of long_description
  * Use request instead of response in cache key callable and ensure
    cache works as expected without always compressing content.
  * Fix indentation in README
  * Added copyright header to flask_compress.py
* Fri May 18 2018 jengelh@inai.de
- The description should not assume any use context.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 1.4.0
  * Added COMPRESS_REGISTER option to selectively register compression
- Implement single-spec version
* Sun Sep 25 2016 mardnh@gmx.de
- initial package, version 1.3.1
